@@ -44,8 +44,7 @@ class MyMemoryTranslator(BaseTranslator):
 
             response = requests.get(self.__base_url,
                                     params=self._url_params,
-                                    headers=self.headers,
-                                    verify=False)
+                                    headers=self.headers)
             data = response.json()
             if not data:
                 raise Exception("Translation was not found in response!")
